Description: Add a missing #include 
 Compilation on s390x and two other platforms fell over because reverse_double(),
 a macro, was seen as undefined. Adding the #include should fix this.
Author: Dirk Eddelbuettel <edd@debian.org>
Last-Update: 2025-11-30

--- gretl-2025c.orig/lib/src/foreign_db.c
+++ gretl-2025c/lib/src/foreign_db.c
@@ -29,6 +29,7 @@
 #include "libgretl.h"
 #include "dbread.h"
 #include "foreign_db.h"
+#include "swap_bytes.h"
 
 #define RATSCOMMENTLENGTH 80
 #define RATSCOMMENTS 2
